@@ -111,17 +111,16 @@ class DBBase:
         :param sql: the parameterized sql to execute
         :param params: a list of params
         """
-
         await self.auto_open()
-
         start = time()
 
-        if params:
-            await self.conn.execute(sql, *params)
-        else:
-            await self.conn.execute(sql)
-
-        self.log(sql, params, time() - start)
+        try:
+            if params:
+                await self.conn.execute(sql, *params)
+            else:
+                await self.conn.execute(sql)
+        finally:
+            self.log(sql, params, time() - start)
 
     async def executemany(self, sql: str, params: Optional[List[Iterable[Any]]] = None):
         """This method passes through to self.conn.execute.
@@ -129,17 +128,16 @@ class DBBase:
         :param sql: the parameterized sql to execute
         :param params: a list of params
         """
-
         await self.auto_open()
-
         start = time()
 
-        if params:
-            await self.conn.executemany(sql, params)
-        else:
-            await self.conn.executemany(sql)
-
-        self.log(sql, params, time() - start)
+        try:
+            if params:
+                await self.conn.executemany(sql, params)
+            else:
+                await self.conn.executemany(sql)
+        finally:
+            self.log(sql, params, time() - start)
 
     async def fetch(
         self, sql: Optional[str], params: Optional[Params] = None
@@ -153,10 +151,9 @@ class DBBase:
             raise Exception("No SQL provided")
 
         await self.auto_open()
+        start = time()
 
         try:
-            start = time()
-
             if params:
                 return await self.conn.fetch(sql, *params)
 
@@ -176,7 +173,6 @@ class DBBase:
             raise Exception("No SQL provided")
 
         await self.auto_open()
-
         start = time()
 
         try:
